# Generated by Django 4.0.3 on 2022-04-29 06:50

import django
if django.VERSION > (4, 0):
    from django.db.models import JSONField
else:
    from django.contrib.postgres.fields import JSONField
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('notice', '0006_backlog_creator_backlog_title_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='privatenotice',
            name='content',
        ),
        migrations.AddField(
            model_name='privatenotice',
            name='business_type',
            field=models.CharField(default='', max_length=64, verbose_name='business type'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='privatenotice',
            name='data',
            field=JSONField(null=True, verbose_name='data'),
        ),
        migrations.AddField(
            model_name='privatenotice',
            name='is_node_done',
            field=models.BooleanField(default=False, verbose_name='completed status'),
        ),
        migrations.AddField(
            model_name='privatenotice',
            name='node',
            field=models.CharField(default='', max_length=64, verbose_name='node'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='privatenotice',
            name='obj_key',
            field=models.CharField(default='', max_length=64, verbose_name='obj key'),
            preserve_default=False,
        ),
    ]



# Generated by Django 4.0.3 on 2022-04-27 06:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('notice', '0005_backlog_privatenotice'),
    ]

    operations = [
        migrations.AddField(
            model_name='backlog',
            name='creator',
            field=models.CharField(max_length=64, null=True, verbose_name='creator'),
        ),
        migrations.AddField(
            model_name='backlog',
            name='title',
            field=models.CharField(max_length=64, null=True, verbose_name='title'),
        ),
        migrations.AlterField(
            model_name='privatenotice',
            name='creator',
            field=models.CharField(max_length=64, null=True, verbose_name='creator'),
        ),
    ]



# Generated by Django 4.0.3 on 2022-04-19 08:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('notice', '0002_remove_noticestore_receiver_type_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='receivertag',
            name='receiver_id',
        ),
        migrations.AddField(
            model_name='receivertag',
            name='receiver',
            field=models.CharField(default='', max_length=64, verbose_name='receiver'),
            preserve_default=False,
        ),
    ]



# Generated by Django 4.0.3 on 2022-05-27 09:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('notice', '0009_rename_handler_backlog_handlers_backlog_cc_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='backlog',
            name='cc',
        ),
        migrations.RemoveField(
            model_name='backlog',
            name='cc_type',
        ),
        migrations.AddField(
            model_name='backlog',
            name='initiated_at',
            field=models.DateTimeField(null=True, verbose_name='initiated datetime'),
        ),
        migrations.AddField(
            model_name='backlog',
            name='obj_associated_data',
            field=models.CharField(max_length=64, null=True, verbose_name='obj associated data'),
        ),
        migrations.AddField(
            model_name='backlog',
            name='obj_associated_data_type',
            field=models.CharField(max_length=64, null=True, verbose_name='obj associated data type'),
        ),
        migrations.AddField(
            model_name='backlog',
            name='obj_node',
            field=models.CharField(max_length=64, null=True, verbose_name='obj node'),
        ),
    ]



# Generated by Django 4.0.4 on 2022-05-23 11:39
import django

if django.VERSION > (4, 0):
    from django.db.models import JSONField
else:
    from django.contrib.postgres.fields import JSONField
import django.contrib.postgres.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('notice', '0004_alter_receivertag_noticestore'),
    ]

    operations = [
        migrations.CreateModel(
            name='Backlog',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='create time')),
                ('updated_at', models.DateTimeField(auto_now=True, verbose_name='latest update time')),
                ('receiver', models.CharField(max_length=64, verbose_name='receiver')),
                ('is_read', models.BooleanField(default=False, verbose_name='read status')),
                ('read_at', models.DateTimeField(null=True, verbose_name='read time')),
                ('data', JSONField(null=True, verbose_name='data')),
                ('is_done', models.BooleanField(default=False, verbose_name='completed status')),
                ('done_at', models.DateTimeField(null=True, verbose_name='completed datetime')),
                ('handler', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=64), null=True, size=None, verbose_name='handler')),
                ('initiator', models.CharField(max_length=64, null=True, verbose_name='initiator')),
                ('initiator_name', models.CharField(max_length=64, null=True, verbose_name='initiator name')),
                ('obj_name', models.CharField(max_length=64, null=True, verbose_name='obj name')),
                ('obj_key', models.CharField(max_length=64, null=True, verbose_name='obj key')),
                ('obj_status', models.CharField(max_length=64, null=True, verbose_name='obj status')),
                ('batch', models.CharField(max_length=36, null=True, verbose_name='batch')),
                ('candidates', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=64), null=True, size=None, verbose_name='candidates')),
            ],
            options={
                'db_table': 'notice_backlog',
            },
        ),
        migrations.CreateModel(
            name='PrivateNotice',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='create time')),
                ('updated_at', models.DateTimeField(auto_now=True, verbose_name='latest update time')),
                ('creator', models.CharField(max_length=64, null=True, verbose_name='creator')),
                ('receiver', models.CharField(max_length=64, verbose_name='receiver')),
                ('content', models.TextField(null=True, verbose_name='content')),
                ('title', models.CharField(max_length=64, null=True, verbose_name='title')),
                ('is_read', models.BooleanField(default=False, verbose_name='read status')),
                ('read_at', models.DateTimeField(null=True, verbose_name='read time')),
            ],
            options={
                'db_table': 'notice_private_notice',
            },
        ),
    ]



# Generated by Django 4.0.3 on 2022-05-07 10:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('notice', '0007_remove_privatenotice_content_and_more'),
    ]

    operations = [

        migrations.RemoveField(
            model_name='backlog',
            name='title',
        ),
        migrations.RemoveField(
            model_name='privatenotice',
            name='business_type',
        ),
        migrations.RemoveField(
            model_name='privatenotice',
            name='is_node_done',
        ),
        migrations.RemoveField(
            model_name='privatenotice',
            name='node',
        ),
        migrations.RemoveField(
            model_name='privatenotice',
            name='obj_key',
        ),
    ]



# Generated by Django 4.0.3 on 2022-05-29 03:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('notice', '0010_remove_backlog_cc_remove_backlog_cc_type_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='backlog',
            name='obj_node',
        ),
        migrations.AddField(
            model_name='backlog',
            name='is_deleted',
            field=models.BooleanField(default=False, verbose_name='delete tag'),
        ),
    ]



# Generated by Django 4.0.3 on 2022-04-19 09:05

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('notice', '0003_remove_receivertag_receiver_id_receivertag_receiver'),
    ]

    operations = [
        migrations.AlterField(
            model_name='receivertag',
            name='noticestore',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='notice.noticestore', verbose_name='notice'),
        ),
    ]



# Generated by Django 4.0.3 on 2022-05-27 08:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('notice', '0008_remove_backlog_redirect_url_remove_backlog_title_and_more'),
    ]

    operations = [
        migrations.RenameField(
            model_name='backlog',
            old_name='handler',
            new_name='handlers',
        ),
        migrations.AddField(
            model_name='backlog',
            name='cc',
            field=models.CharField(max_length=64, null=True, verbose_name='cc'),
        ),
        migrations.AddField(
            model_name='backlog',
            name='cc_type',
            field=models.CharField(max_length=64, null=True, verbose_name='cc type'),
        ),
        migrations.AddField(
            model_name='backlog',
            name='company',
            field=models.CharField(max_length=64, null=True, verbose_name='company type'),
        ),
        migrations.AddField(
            model_name='backlog',
            name='company_type',
            field=models.CharField(max_length=64, null=True, verbose_name='company type'),
        ),
        migrations.AddField(
            model_name='privatenotice',
            name='content',
            field=models.TextField(null=True, verbose_name='content'),
        ),
    ]
